==> haskell-erf-2.0.0.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-erf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 erf
version:              2.0.0.0
visibility:           public
id:                   erf-2.0.0.0-11yD1QoQ6BY5Qcj00a1c17
key:                  erf-2.0.0.0-11yD1QoQ6BY5Qcj00a1c17
license:              BSD-3-Clause
maintainer:           Lennart Augustsson
author:               Lennart Augustsson
stability:            experimental
synopsis:             The error function, erf, and related functions.
description:
    A type class for the error function, erf, and related functions.
    Instances for Float and Double.

category:             Math
abi:                  7c13e7274f7ea85b78f1b9e251e1eb31
exposed:              True
exposed-modules:      Data.Number.Erf
import-dirs:          /usr/lib/ghc-8.8.3/site-local/erf-2.0.0.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/erf-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/erf-2.0.0.0
hs-libraries:         HSerf-2.0.0.0-11yD1QoQ6BY5Qcj00a1c17
depends:              base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-erf/html/erf.haddock
haddock-html:         /usr/share/doc/haskell-erf/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-erf-2.0.0.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-erf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 erf
version:              2.0.0.0
visibility:           public
id:                   erf-2.0.0.0-5QfSgjMZlFpBfHYjrXsgks
key:                  erf-2.0.0.0-5QfSgjMZlFpBfHYjrXsgks
license:              BSD-3-Clause
maintainer:           Lennart Augustsson
author:               Lennart Augustsson
stability:            experimental
synopsis:             The error function, erf, and related functions.
description:
    A type class for the error function, erf, and related functions.
    Instances for Float and Double.

category:             Math
abi:                  591caced3ed51647b6d6633f0a7c8308
exposed:              True
exposed-modules:      Data.Number.Erf
import-dirs:          /usr/lib/ghc-8.10.1/site-local/erf-2.0.0.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/erf-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/erf-2.0.0.0
hs-libraries:         HSerf-2.0.0.0-5QfSgjMZlFpBfHYjrXsgks
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-erf/html/erf.haddock
haddock-html:         /usr/share/doc/haskell-erf/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
